@@ -2,6 +2,7 @@ import logging
 from typing import Dict, Optional
 
 from dynatrace.configuration_v1.alerting_profiles import AlertingProfileService
+from dynatrace.configuration_v1.anomaly_detection_process_groups import AnomalyDetectionPGService
 from dynatrace.configuration_v1.dashboard import DashboardService
 from dynatrace.configuration_v1.extensions import ExtensionService
 from dynatrace.configuration_v1.maintenance_windows import MaintenanceWindowService
@@ -11,7 +12,9 @@ from dynatrace.configuration_v1.plugins import PluginService
 from dynatrace.environment_v1.cluster_time import ClusterTimeService
 from dynatrace.environment_v1.custom_device import CustomDeviceService
 from dynatrace.environment_v1.event import EventService
+from dynatrace.environment_v1.synthetic_monitors import SyntheticMonitorsService
 from dynatrace.environment_v1.synthetic_third_party import ThirdPartySyntheticTestsService
+from dynatrace.environment_v1.timeseries import TimeSerieService
 from dynatrace.environment_v2.activegates import ActiveGateService
 from dynatrace.environment_v2.activegates_autoupdate_configuration import ActiveGateAutoUpdateConfigurationService
 from dynatrace.environment_v2.activegates_autoupdate_jobs import ActiveGateAutoUpdateJobsService
@@ -56,6 +59,7 @@ class Dynatrace:
         self.alerting_profiles: AlertingProfileService = AlertingProfileService(self.__http_client)
         self.anomaly_detection_metric_events = MetricEventService(self.__http_client)
         self.audit_logs: AuditLogsService = AuditLogsService(self.__http_client)
+        self.anomaly_detection_process_groups = AnomalyDetectionPGService(self.__http_client)
         self.cluster_time: ClusterTimeService = ClusterTimeService(self.__http_client)
         self.custom_devices: CustomDeviceService = CustomDeviceService(self.__http_client)
         self.dashboards: DashboardService = DashboardService(self.__http_client)
@@ -66,6 +70,8 @@ class Dynatrace:
         self.metrics: MetricService = MetricService(self.__http_client)
         self.notifications: NotificationService = NotificationService(self.__http_client)
         self.plugins: PluginService = PluginService(self.__http_client)
+        self.synthetic_monitors: SyntheticMonitorsService = SyntheticMonitorsService(self.__http_client)
         self.tenant_tokens = TenantTokenService(self.__http_client)
         self.third_part_synthetic_tests: ThirdPartySyntheticTestsService = ThirdPartySyntheticTestsService(self.__http_client)
         self.tokens: TokenService = TokenService(self.__http_client)
+        self.timeseries: TimeSerieService = TimeSerieService(self.__http_client)
