@@ -2,10 +2,21 @@ import warnings
 import functools
 from datetime import datetime
 from typing import Union, Optional
+import unicodedata
+import re
+
 
 ISO_8601 = "%Y-%m-%dT%H:%M:%S.%fZ"
 
 
+def slugify(value):
+    value = str(value)
+    value = unicodedata.normalize("NFKC", value)
+    value = re.sub(r"[:.-/\s]+", "_", value)
+    value = re.sub(r"[^\w\s-]", "", value)
+    return value
+
+
 def deprecated(reason=""):
     def decorator(func):
         @functools.wraps(func)
@@ -28,3 +39,9 @@ def iso8601_to_datetime(timestamp: Optional[str]) -> Optional[datetime]:
     if isinstance(timestamp, str):
         return datetime.strptime(timestamp, ISO_8601)
     return timestamp
+
+
+def int64_to_datetime(timestamp: Optional[int]) -> Optional[datetime]:
+    if timestamp is None or not timestamp:
+        return None
+    return datetime.utcfromtimestamp(timestamp / 1000)
